@@ -71,6 +71,11 @@ centrality <- function(graph,alpha=1,posfun=abs,pkg = c("igraph","qgraph"),all.s
   WeightedDegreesIn <- colSums(posfun(W))
   CombinedDegreesIn <- UnweightedDegreesIn^(1-alpha) * WeightedDegreesIn^alpha
   
+  # Expected Influence
+  InExpectedInfluence <- colSums(W)
+  OutExpectedInfluence <- rowSums(W)
+  
+  
   DistMat <- 1/(ifelse(posfun(W)==0,0,posfun(W)^alpha))
   if (pkg=="igraph"){
     igraphObject <- igraph::graph.adjacency(DistMat, weighted = TRUE, mode = "directed")
@@ -212,6 +217,8 @@ centrality <- function(graph,alpha=1,posfun=abs,pkg = c("igraph","qgraph"),all.s
     InDegree = lab(CombinedDegreesIn,Labels),
     Closeness = lab(Closeness,Labels),
     Betweenness = lab(Betweenness,Labels),
+    InExpectedInfluence = InExpectedInfluence,
+    OutExpectedInfluence = OutExpectedInfluence,
     ShortestPathLengths = lab(ShortestPaths,Labels),
     ShortestPaths = lab(Paths,Labels))
   
